

import UIKit
import T1Autograph

class ViewController: UIViewController, T1AutographDelegate {
	
	var autograph: T1Autograph = T1Autograph()
	var autographModal: T1Autograph = T1Autograph()
	
	@IBOutlet var outputImage: UIImageView?
	@IBOutlet var autographView: UIView?
	
	
	override func viewDidLoad() {
		super.viewDidLoad()
		
		autograph = T1Autograph.autograph(withView: autographView, delegate: self) as! T1Autograph
        // for com.tenonedesign.T1AutographDemoSwift
		autograph.licenseCode = "2412e5e98f3cdf15174af801c60447cd1f9db35a"
		
		// Clips signature UIImage to the bounds of the signature capture UIView.  Default is NO
		//	autograph.clipSignatureToBounds = true

		// show signature guideline.  Default is YES
		//	autograph.showGuideline = false

		// set export color.  Default is blackColor
		//	autograph.strokeColor = UIColor.darkGray

		// set stroke width.  Default is 6
		//	autograph.strokeWidth = 3

		// set amount of stroke width reduction from velocity.  Default is 0.85
		//	autograph.velocityReduction = 0.5

		// set export size.  Default scale is 1.0
		//	autograph.exportScale = 0.5

		// show current date.  Default is NO
		//	autograph.showDate = true

		// add current time to signature.  Requires showDate == YES.  Default is NO
		//	autograph.dateIncludesTime = true

		// show unique signature identifier.  Default is NO
		//	autograph.showHash = true

		// customize signature identifier.  Default is nil.  Use no more than 10 characters.
		//	autograph.customHash = "DocumentID"

		// enable 3-finger swipe to undo.  Default is YES
		//	autograph.swipeToUndoEnabled = false
		
        print("autograph version \(self.autograph.buildNumber)")
        print("autograph license code \(self.autograph.licenseCode ?? "")")
        print("app bundle identifier \(Bundle.main.bundleIdentifier ?? "")")
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}
	
	@IBAction func showModalButtonAction(_ sender: AnyObject) {
		
		autographModal = T1Autograph.autograph(withDelegate: self, modalDisplay: "Hello, hope you’re having a good day!") as! T1Autograph
		
		// Enter license code here to remove the watermark
		autographModal.licenseCode = "2412e5e98f3cdf15174af801c60447cd1f9db35a"
		
		// any optional configuration done here
		autographModal.strokeColor = UIColor.darkGray
	}
	
	@IBAction func clearButtonAction(_ sender: AnyObject) {
		autograph.reset(sender)
	}
	@IBAction func doneButtonAction(_ sender: AnyObject) {
		autograph.done(sender)
		autograph.reset(sender)
	}

	
	
	
// MARK: - T1Autograph delegate
	
	func autograph(_ autograph: T1Autograph!, didCompleteWith signature: T1Signature!) {
		NSLog("-- Autograph signature completed. --")
		outputImage?.image = signature.imageView.image
	}
	
	func autographDidCancelModalView(_ autograph: T1Autograph!) {
		NSLog("Autograph modal signature has been cancelled")
	}
	
	func autographDidCompleteWithNoSignature(_ autograph: T1Autograph!) {
		NSLog("User pressed the done button without signing")
	}
	
	func autograph(_ autograph: T1Autograph!, didEndLineWithSignaturePointCount count: UInt) {
		NSLog("Line ended with total signature point count of %d", count)
		// Note: You can use the 'count' parameter to determine if the line is substantial enough to enable the done or clear button.
	}
	
	func autograph(_ autograph: T1Autograph!, willCompleteWith signature: T1Signature!) {
		NSLog("Autograph will complete with signature")
	}
}

